@@ -70,7 +70,7 @@ def get_synchronization_tasks(object_name):
               'depend': AllTasks.failed_all("check_current_binhost")
              },
              {'name': 'check_chosen_binhost',
-              'message': __("Checking chosen binhost"),
+              'message': _("Checking chosen binhost"),
               'method': Object('check_chosen_binhost(update.cl_update_binhost_choice)'),
               'condition': lambda GetBool, Get: (
                   not GetBool('update.cl_update_binhost_recheck_set') and
@@ -345,7 +345,9 @@ class ClUpdateAction(Action):
                         '"-uDN","@world")',
               }
          ],
-         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
+         'condition': lambda Get: (Get('cl_update_sync_only_set') == 'off' and
+                                   (Get('update.cl_update_outdate_set') == 'on' or
+                                    Get('cl_update_settings_changes_set') == 'on'))
          },
         {'name': 'update_other:update_perl',
          'group': __("Updating Perl modules"),
@@ -441,7 +443,7 @@ class ClUpdateAction(Action):
          'essential': False,
          'condition': lambda Get: (Get('cl_update_sync_only_set') == 'off' and \
                 Get('cl_update_pretend_set') == 'off' and \
-                UpdateConditions.check_world_updated_after_tag_save()()) 
+                UpdateConditions.check_world_updated_after_tag_save()())
         },
         ] + get_synchronization_tasks("Update") + [
         {'name': 'system_configuration',
@@ -483,10 +485,7 @@ class ClUpdateAction(Action):
          'depend': Tasks.failed_all("check_schedule")
          },
         # сообщение удачного завершения при обновлении ревизии
-        {'name': 'update:save_portage_hash',
-         'method': 'Update.save_portage_state_hash()',
-         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
-         },
+
         {'name': 'drop_portage_hash',
          'method': 'Update.drop_portage_state_hash()',
          'depend': Tasks.failed()
@@ -507,6 +506,10 @@ class ClUpdateAction(Action):
                 Get('cl_update_pretend_set') == 'off',
          'decoration': 'Update.update_task("%s")' % EmergeMark.SaveTag
          },
+        {'name': 'update:save_portage_hash',
+         'method': 'Update.save_portage_state_hash()',
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
+         },
         {'name': 'clear_migration_host',
          'method': 'Update.delete_binhost()',
          'depend': (Tasks.hasnot("check_schedule")), 
